diff --git a/vim.spec b/vim.spec
index f17f6ca..dbecc9a 100644
--- a/vim.spec
+++ b/vim.spec
@@ -21,7 +21,7 @@ Summary: The VIM editor
 URL:     http://www.vim.org/
 Name: vim
 Version: %{baseversion}.%{patchlevel}
-Release: 1%{?dist}
+Release: 2%{?dist}
 License: Vim and MIT
 Source0: ftp://ftp.vim.org/pub/vim/unix/vim-%{baseversion}-%{patchlevel}.tar.bz2
 Source1: vim.sh
@@ -827,6 +827,9 @@ touch %{buildroot}/%{_datadir}/%{name}/vimfiles/doc/tags
 %config(noreplace) %{_sysconfdir}/profile.d/vim-default-editor.*
 
 %changelog
+* Thu Feb 04 2021 Zdenek Dohnal <zdohnal@redhat.com> - 2:8.2.2451-2
+- vim-update.sh: apply changes master->rawhide
+
 * Tue Feb 02 2021 Zdenek Dohnal <zdohnal@redhat.com> - 2:8.2.2451-1
 - patchlevel 2451
diff --git a/vim-update.sh b/vim-update.sh
index 34347b8..5c88d20 100755
--- a/vim-update.sh
+++ b/vim-update.sh
@@ -1,7 +1,7 @@
 #!/bin/bash
 debug=""
 #debug="echo "
-branches=( "master" "f33" "f32" )
+branches=( "rawhide" "f33" "f32" )
 releases=( "fc34" "fc33" "fc32" )
 regexps=( "fc34" "\|fc33" "\|fc32" )
 bodhi_enabled=( "0" "1" "1" )
@@ -74,8 +74,8 @@ mv dist/vim-${UPSTREAMMAJOR}.tar.bz2 dist/vim-${UPSTREAMMAJOR}-${LASTPLFILLED}.t
 popd
 
 cp -f vim-upstream/dist/vim-${UPSTREAMMAJOR}-${LASTPLFILLED}.tar.bz2 .
-#wget https://raw.githubusercontent.com/ignatenkobrain/vim-spec-plugin/master/ftplugin/spec.vim -O ftplugin-spec.vim
-#wget https://raw.githubusercontent.com/ignatenkobrain/vim-spec-plugin/master/syntax/spec.vim -O syntax-spec.vim
+#wget https://raw.githubusercontent.com/ignatenkobrain/vim-spec-plugin/rawhide/ftplugin/spec.vim -O ftplugin-spec.vim
+#wget https://raw.githubusercontent.com/ignatenkobrain/vim-spec-plugin/rawhide/syntax/spec.vim -O syntax-spec.vim
 if [ $CHANGES -ne 0 ]; then
    CHLOG="* $DATE $PACKAGER -$EPOCH:$UPSTREAMMAJOR"
    $debug sed -i -e "/Release: /cRelease: 1%{?dist}" $SPEC
@@ -166,8 +166,8 @@ if [ $CHANGES -ne 0 ]; then
      if [ "$testing_update" == "" ] && [ $done_build -eq 1 ]; then
        $debug fedpkg build
        if [ $? -eq 0 ]; then
-         # if branch isn't master or branch is enabled in bodhi, create update
-         if [ $branch != "master" ] || [ ${bodhi_enabled[@]: $bodhi_enabled_index: 1} -eq 1 ]; then
+         # if branch isn't rawhide or branch is enabled in bodhi, create update
+         if [ $branch != "rawhide" ] || [ ${bodhi_enabled[@]: $bodhi_enabled_index: 1} -eq 1 ]; then
            $debug bodhi updates new --user zdohnal --type enhancement --notes "The newest upstream commit" --request testing --autotime --autokarma --stable-karma 3 --unstable-karma -3 vim-${UPSTREAMMAJOR}.${LASTPLFILLED}-1.${releases[@]: $release_index: 1}
          fi
        else
@@ -194,7 +194,7 @@ if [ $CHANGES -ne 0 ]; then
    #fi
 fi
 
-#go back to master
-$debug fedpkg switch-branch master
+#go back to rawhide
+$debug fedpkg switch-branch rawhide
 
 exit 0